#!/bin/sh

echo -e "\033[36mKuboardEndpoint           :\033[0m ${KUBOARD_ENDPOINT}"
echo -e "\033[36mKuboardAgent              :\033[0m ${KUBOARD_AGENT_PROTOCOL}://${KUBOARD_AGENT_HOST}:${KUBOARD_AGENT_PORT}"
echo -e "\033[36mKUBOARD_AGENT_PROXY       :\033[0m ${KUBOARD_AGENT_PROXY}"
echo -e "\033[36mKUBOARD_AGENT_KEY         :\033[0m ${KUBOARD_AGENT_KEY}"
echo -e "\033[36mKUBOARD_K8S_CLUSTER_NAME  :\033[0m ${KUBOARD_K8S_CLUSTER_NAME}"
echo -e "\033[36mKUBOARD_ANONYMOUS_TOKEN   :\033[0m ${KUBOARD_ANONYMOUS_TOKEN}"

if [ x"${KUBOARD_ENDPOINT}" = x ] || [ x"${KUBOARD_AGENT_HOST}" = x ] || [ x"${KUBOARD_AGENT_PORT}" = x ] || [ x"${KUBOARD_AGENT_KEY}" = x ] || [ x"${KUBOARD_K8S_CLUSTER_NAME}" = x ] || [ x"${KUBOARD_AGENT_REMOTE_PORT}" = x ]; then
  echo "环境变量 KUBOARD_ENDPOINT / KUBOARD_AGENT_HOST / KUBOARD_AGENT_PORT / KUBOARD_AGENT_KEY / KUBOARD_K8S_CLUSTER_NAME 不能为空"
  exit;
fi

echo " "

KUBOARD_AGENT_REMOTE_PORT_NGINX=$((${KUBOARD_AGENT_REMOTE_PORT} + 10000))

echo "KUBOARD_AGENT_REMOTE_PORT_NGINX: ${KUBOARD_AGENT_REMOTE_PORT_NGINX}"

sed -i s/KUBOARD_AGENT_REMOTE_PORT_NGINX/"${KUBOARD_AGENT_REMOTE_PORT_NGINX}"/g /etc/kuboard/kuboard-agent.ini

sed -i s/KUBOARD_AGENT_HOST/"${KUBOARD_AGENT_HOST}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_AGENT_PORT/"${KUBOARD_AGENT_PORT}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_AGENT_REMOTE_PORT/"${KUBOARD_AGENT_REMOTE_PORT}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_AGENT_PROTOCOL/"${KUBOARD_AGENT_PROTOCOL}"/g /etc/kuboard/kuboard-agent.ini
sed -i 's#'''KUBOARD_AGENT_PROXY'''#'''${KUBOARD_AGENT_PROXY}'''#g' /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_AGENT_KEY/"${KUBOARD_AGENT_KEY}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_K8S_CLUSTER_NAME/"${KUBOARD_K8S_CLUSTER_NAME}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_API_LOCAL_IP/"${KUBERNETES_SERVICE_HOST}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/KUBOARD_API_LOCAL_PORT/"${KUBERNETES_SERVICE_PORT}"/g /etc/kuboard/kuboard-agent.ini
sed -i s/POD_HOST_NAME/"$(hostname)"/g /etc/kuboard/kuboard-agent.ini

KUBERNETES_TOKEN=""
if [ -f "/run/secrets/kubernetes.io/serviceaccount/token" ]
then
  read KUBERNETES_TOKEN < /run/secrets/kubernetes.io/serviceaccount/token
elif [ -f "/var/run/secrets/kubernetes.io/serviceaccount/token" ]
then
  read KUBERNETES_TOKEN < /var/run/secrets/kubernetes.io/serviceaccount/token
else
  echo -e "\033[31m未在如下路径找到 token\033[0m"
  echo "/run/secrets/kubernetes.io/serviceaccount/token"
  echo "/var/run/secrets/kubernetes.io/serviceaccount/token"
  exit;
fi

KUBOARD_AGENT_VERSION=""
read KUBOARD_AGENT_VERSION < /kuboard-agent-version.json

K8S_VERSION=$(curl -k "https://${KUBERNETES_SERVICE_HOST}:${KUBERNETES_SERVICE_PORT}/version" \
  -H 'Cache-Control: no-cache' \
  -H 'Accept: application/json, text/plain, */*' \
  -H "Authorization: Bearer ${KUBERNETES_TOKEN}" \
  --compressed --insecure)

echo " "
echo "K8S_VERSION:"
echo ${K8S_VERSION}
echo " "
echo "AGENT_VERSION:"
echo ${KUBOARD_AGENT_VERSION}
echo " "

export http_proxy=${KUBOARD_AGENT_PROXY}
export https_proxy=${KUBOARD_AGENT_PROXY}

postResult=$(curl -k --location --request POST "${KUBOARD_ENDPOINT}/kuboard-api/cluster/${KUBOARD_K8S_CLUSTER_NAME}/kind/KubernetesClusterToken" \
--header 'Content-Type: application/json' \
--header 'Accept: application/json' \
--data-raw "{
    \"kind\": \"KubernetesClusterToken\",
    \"metadata\": {
        \"cluster\": \"${KUBOARD_K8S_CLUSTER_NAME}\",
        \"name\": \"${KUBERNETES_TOKEN_NAME}\",
        \"annotations\": {
            \"description\": \"ServiceAccount Token for Cluster ${KUBOARD_K8S_CLUSTER_NAME}\"
        }
    },
    \"spec\": {
        \"token\": \"${KUBERNETES_TOKEN}\",
        \"anonymousToken\": \"${KUBOARD_ANONYMOUS_TOKEN}\",
        \"agentVersion\": ${KUBOARD_AGENT_VERSION},
        \"kubernetesVersion\": ${K8S_VERSION}
    }
}")

echo " "

postResultPass=$(echo $postResult | grep "${KUBOARD_AGENT_VERSION}")

if [ x"${postResultPass}" != x"" ]; then
  echo -e "\033[32m成功更新 kuboard-admin Token\033[0m ${KUBOARD_ENDPOINT}/kuboard-api/cluster/${KUBOARD_K8S_CLUSTER_NAME}/kind/KubernetesClusterToken"
else
  echo -e "\033[31m访问 kuboard-server 失败\033[0m ${KUBOARD_ENDPOINT}/kuboard-api/cluster/${KUBOARD_K8S_CLUSTER_NAME}/kind/KubernetesClusterToken"
  echo ${postResult}
  exit 1
fi
  

echo " "
echo -e "\033[32mStart Kuboard Agent\033[0m"
echo " "
kuboard-agent -c /etc/kuboard/kuboard-agent.ini &


nameserver=''

if [ -n "${KUBE_DNS_SERVICE_HOST}" ]; then
  echo "DNS from env: ${KUBE_DNS_SERVICE_HOST}:${KUBE_DNS_SERVICE_PORT}"
  nameserver=${KUBE_DNS_SERVICE_HOST}:${KUBE_DNS_SERVICE_PORT}
  echo "nameserver is resolved from \${KUBE_DNS_SERVICE_HOST}:\${KUBE_DNS_SERVICE_PORT} ${nameserver}"
else
  echo ">>>>>>/etc/resolv.conf"
  cat /etc/resolv.conf
  echo "<<<<<</etc/resolv.conf"
  echo $(sed -n '/nameserver/p' /etc/resolv.conf)
  nameserver=$(sed -n '/nameserver/p' /etc/resolv.conf)
  nameserver=${nameserver:11}
  echo "nameserver is resolved from /etc/resolv.conf, and value is ${nameserver}"
fi

echo "start kagent"
./kagent &

echo "nameserver is [${nameserver}]"

sed -i s/NAMESERVER/${nameserver}/g /etc/nginx/conf.d/nginx.80.conf


echo "start nginx"
nginx -g "daemon off;"
